netapp_ontap.models.firmware_disk API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.firmware_disk`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class FirmwareDiskSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the FirmwareDisk object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `average_duration_per_disk GET`

    Average firmware update duration per disk (in seconds).

    Example: 120

  `num_waiting_download GET`

    The number of disks waiting to download the firmware update.

    Example: 0

  `total_completion_estimate GET`

    Estimated firmware update duration to completion (in minutes).

    Example: 0

  `update_status GET`

    Status of the background disk firmware update.

    Valid choices:

    - running
    - idle